@@ -1,16 +1,12 @@
-# $Header: /home/fergal/my/cvs/Exporter-Easy/lib/Exporter/Easy.pm,v 1.24 2003/02/14 16:53:20 fergal Exp $
-
-use strict;
-
 package Exporter::Easy;
-
-require 5.006;
+$Exporter::Easy::VERSION = '0.18';
+use 5.006;
+use strict;
+use warnings;
 
 require Exporter;
-
 use vars;
 
-our $VERSION = '0.15';
 
 sub import
 {
@@ -269,7 +265,8 @@ In other files which wish to use YourModule:
 
 =head1 DESCRIPTION
 
-Exporter::Easy makes using Exporter easy. In it's simplest case it allows
+Exporter::Easy makes using Exporter easy.
+In its simplest case, it allows
 you to drop the boilerplate code that comes with using Exporter, so
 
   require Exporter;
@@ -405,8 +402,52 @@ all symbols anyway).
 
 =head1 SEE ALSO
 
-For details on what all these arrays and hashes actually do, see the
-Exporter documentation.
+L<Exporter> is the grandaddy of all Exporter modules, and bundled with Perl
+itself, unlike the rest of the modules listed here. Look at the documentation
+for this module to see more explanation of the OK, EXPORT and other variables.
+
+L<Attribute::Exporter> defines attributes which you use to mark
+which subs and variables you want to export, and how.
+
+L<Exporter::Simple> also uses attributes to control the export of
+functions and variables from your module.
+
+L<Const::Exporter> makes it easy to create a module that exports constants.
+
+L<Constant::Exporter> is another module that makes it easy to create
+modules that define and export constants.
+
+L<Sub::Exporter> is a "sophisticated exporter for custom-built routines";
+it lets you provide generators that can be used to customise what
+gets imported when someone uses your module.
+
+L<Exporter::Tiny> provides the same features as L<Sub::Exporter>,
+but relying only on core dependencies.
+
+L<Exporter::Shiny> is a shortcut for L<Exporter::Tiny> that
+provides a more concise notation for providing optional exports.
+
+L<Exporter::Declare> provides syntactic sugar to make the export
+status of your functions part of their declaration. Kind of.
+
+L<AppConfig::Exporter> lets you export part of an L<AppConfig>-based
+configuration.
+
+L<Exporter::Lexical> lets you export lexical subs from your module.
+
+L<Constant::Exporter::Lazy> lets you write a module that exports
+function-style constants, which are instantiated lazily.
+
+L<Exporter::Auto> will export everything from your module that
+it thinks is a public function (name doesn't start with an underscore).
+
+L<Class::Exporter> lets you export class methods as regular subroutines.
+
+L<Xporter> is like Exporter, but with persistent defaults and auto-ISA.
+
+=head1 REPOSITORY
+
+L<https://github.com/neilb/Exporter-Easy>
 
 =head1 AUTHOR
 
